@@ -28,21 +28,28 @@
 #include <QCleanlooksStyle>
 #include <QColorGroup>
 #include <QTimer>
+#include <QMaemo5InformationBox>
 
 #include <X11/extensions/Xrender.h>
 
 int main(int argc, char **argv)
 {
+	/*
     qWarning("Please make sure you're running a composition manager!");
     Display *dpy = XOpenDisplay(0); // open default display
     if (!dpy) {
         qWarning("Cannot connect to the X server");
         exit(1);
     }
+	*/
 
-    QApplication app(dpy, argc, argv);
+    //QApplication app(dpy, argc, argv);
+    QApplication app(argc, argv);
 
     Widget w;
+	//w.setAttribute(Qt::WA_Maemo5DesktopApplet, true);
+
+	QMaemo5InformationBox::information(&w, "<font color=#000000>Batlevel is now on your desktop, this window will automatically close</font>", QMaemo5InformationBox::DefaultTimeout);
 
     w.show();
 
