@@ -45,6 +45,9 @@
 #include <QUrl>
 #include <QMaemo5InformationBox>
 #include <QDebug>
+#include <QDBusConnection>
+#include <mce/dbus-names.h>
+#include <mce/mode-names.h>
 
 
 #include <X11/Xlib.h>
@@ -55,7 +58,7 @@
 
 #include <QtGui/QMessageBox>
 
-Widget::Widget(QWidget *parent) : QProgressBar (parent), _pollingInterval(10) // 10 min default polling
+Widget::Widget(QWidget *parent) : QProgressBar (parent), _screenOff(false), _pollingInterval(10) // 10 min default polling
 {
     QCoreApplication::instance()->setApplicationName("Hildon-Desktop battery level widget");
 
@@ -64,7 +67,6 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent), _pollingInterval(10) //
     Atom homeAppletAtom = XInternAtom(QX11Info::display(), "_HILDON_WM_WINDOW_TYPE_HOME_APPLET", false);
     Atom appletIDAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_ID", false);
     Atom utf8Atom = XInternAtom(QX11Info::display(), "UTF8_STRING", false); 
-    Atom appletSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SETTINGS", false);
    
     // Set correct window type
     XChangeProperty(QX11Info::display(), winId(), winTypeAtom, XA_ATOM, 32,
@@ -76,11 +78,17 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent), _pollingInterval(10) //
     	            PropModeReplace, (unsigned char *)id.constData(), id.length());
 
     // Add setting button. This button is shown when hildon-desktop is in edit mode. 
+    Atom appletSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SETTINGS", false);
     int settings = 0;
     XChangeProperty(QX11Info::display(), winId(), appletSettingAtom, XA_CARDINAL, 32,
 		    PropModeReplace, (unsigned char*)&settings, 1);
    
+
    	// SETTINGS WIDGET STUFF
+	// listen to the display status, if its OFF we shouldnt poll
+	QDBusConnection::systemBus().connect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
+			                			MCE_DISPLAY_SIG, this, SLOT(displayStateChanged(QString)));
+
 	pollSlider = new QSlider(Qt::Horizontal);
 	pollSlider->setRange(0, 60);
 	pollSlider->setSingleStep(1);
@@ -89,6 +97,7 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent), _pollingInterval(10) //
 	pollValueLabel->setText("Polling Interval : " + QString::number(_pollingInterval) + "min");
 
 	// sytle and color widget objects
+	styleWindow = new QMainWindow;
 	styleWidget = new QWidget;
 
 	v1layout = new QVBoxLayout;
@@ -98,9 +107,12 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent), _pollingInterval(10) //
 	backColor = new QPushButton("BACKGROUND COLOR");
 	textColor = new QPushButton("TEXT COLOR");
 	styleButton = new QMaemo5ValueButton("SELECT STYLE");
-	applyOnlyStyleButton = new QPushButton("APPLY ONLY STYLE");
 	styleSelector = new QMaemo5ListPickSelector;
-	styleSelectionModel = new QStandardItemModel(0, 1);
+	styleSelectionModel = new QStandardItemModel;
+	styleSelector->setModel(styleSelectionModel);
+	styleButton->setPickSelector(styleSelector);
+	styleButton->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
+
 	barColorDialog = new QColorDialog;
 	backColorDialog = new QColorDialog;
 	textColorDialog = new QColorDialog;
@@ -111,8 +123,7 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent), _pollingInterval(10) //
 
 	v1layout->addWidget(pollValueLabel);
 	v1layout->addWidget(pollSlider);
-	v1layout->addWidget(styleButton);
-	v1layout->addWidget(applyOnlyStyleButton);
+	v2layout->addWidget(styleButton);
 	v2layout->addWidget(barColor);
 	v2layout->addWidget(backColor);
 	v2layout->addWidget(textColor);
@@ -120,11 +131,12 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent), _pollingInterval(10) //
 	layout->addLayout(v2layout);
 
 	styleWidget->setLayout(layout);
+	styleWindow->setCentralWidget(styleWidget);
+	styleWindow->setWindowTitle("SETTINGS");
 
 	// detailed info window objects
 	_processPtr = new QProcess(this);
 	battInfo = new QTextBrowser;
-	//QMaemo5KineticScroller* ks = new QMaemo5KineticScroller(battInfo);
 	battInfo->setAttribute(Qt::WA_DeleteOnClose);
 	aboutAct = new QAction(tr("&ABOUT"), this);
 	aboutAct->setShortcut(tr("Ctrl+A"));
@@ -132,6 +144,7 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent), _pollingInterval(10) //
 	connect(aboutAct, SIGNAL(triggered()), this , SLOT(showAbout()));
 
 	detailWindow = new QMainWindow;
+	detailWindow->setWindowTitle("OUTPUT of hal-device bme");
     donateAct = new QAction(tr("&DONATE"), this);
     donateAct->setShortcut(tr("Ctrl+D"));
     donateAct->setStatusTip(tr("Donate"));
@@ -158,19 +171,20 @@ Widget::Widget(QWidget *parent) : QProgressBar (parent), _pollingInterval(10) //
 	connect(_processPtr, SIGNAL(finished(int , QProcess::ExitStatus)), this, SLOT(cmdFinished(int , QProcess::ExitStatus)) );
 
 	// connects for the style window
+	connect(styleSelector, SIGNAL(selected(QString)), this, SLOT(applyStyle(QString)));
 	connect(barColor, SIGNAL(clicked()), barColorDialog, SLOT(show()));
 	connect(backColor, SIGNAL(clicked()), backColorDialog, SLOT(show()));
 	connect(textColor, SIGNAL(clicked()), textColorDialog, SLOT(show()));
-	connect(applyOnlyStyleButton, SIGNAL(clicked()), this, SLOT(applyStyle()));
 	connect(barColorDialog, SIGNAL(colorSelected(QColor)), this, SLOT(changeBarColor(QColor)));
 	connect(backColorDialog, SIGNAL(colorSelected(QColor)), this, SLOT(changeBackColor(QColor)));
 	connect(textColorDialog, SIGNAL(colorSelected(QColor)), this, SLOT(changeTextColor(QColor)));
 
+	// polling timer and its connect slot
 	_timer = new QTimer;
 	_timer->start(_pollingInterval*60000);
 	updateBatteryLevel();
 
-	QObject::connect(_timer, SIGNAL(timeout()), this, SLOT(updateBatteryLevel()));
+	connect(_timer, SIGNAL(timeout()), this, SLOT(updateBatteryLevel()));
 
 }
 
@@ -179,32 +193,9 @@ bool Widget::x11Event ( XEvent * event )
 {
   static Atom appletShowSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SHOW_SETTINGS", false);
 
-
   if (event->xclient.message_type == appletShowSettingAtom ) 
   { 
-	if ( _currentStyleText == "")
-	{
-		//qDebug() << "Style is empty so default to Motif";
-		setCurrentStyle(QString("motif"));
-		styleButton->setValueText("motif");
-		QLabel *label1 = new QLabel("<b>Motif<\b> has been used as <b>default style<\b>, you could change it.\nNote::Maemo style doesnt support this feature, it uses theme colours");
-		QMaemo5InformationBox infoBox;
-		infoBox.setWidget(label1);
-	}
-	else
-	{
-		//qDebug() << "Style is " << _currentStyleText;
-		setCurrentStyle(_currentStyleText);
-		styleButton->setValueText(_currentStyleText);
-	}
-
-	//qDebug() << "Here in x11 event "  << currentStyle->objectName();
-
-	styleSelector->setModel(styleSelectionModel);
-	styleButton->setPickSelector(styleSelector);
-	styleButton->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
-
-	styleWidget->show();
+	styleWindow->show();
 	return true;
   }
   return false;
@@ -220,8 +211,11 @@ void Widget::updateBatteryLevel ()
 {
 	QString cmd("/opt/batlevel/bin/run_lshal");
 
-	_processPtr->start(cmd);
-	_processPtr->waitForFinished();
+	if ( !_screenOff )
+	{
+		_processPtr->start(cmd);
+		_processPtr->waitForFinished();
+	}
 }
 
 void Widget::cmdFinished( int exitCode, QProcess::ExitStatus exitStatus )
@@ -245,15 +239,13 @@ void Widget::cmdFinished( int exitCode, QProcess::ExitStatus exitStatus )
 	battInfo->moveCursor(QTextCursor::Start);
 
 	detailWindow->setCentralWidget(battInfo);
-
-
 }
 
 void Widget::changeBarColor(QColor color)
 {
-	QPalette pal = palette();
+	applyStyle(styleButton->valueText());
 
-	setCurrentStyle(styleButton->valueText());
+	QPalette pal = palette();
 
 	pal.setColor ( QPalette::Highlight, color );
 	setPalette(pal);
@@ -261,9 +253,9 @@ void Widget::changeBarColor(QColor color)
 
 void Widget::changeBackColor(QColor color)
 {
-	QPalette pal = palette();
+	applyStyle(styleButton->valueText());
 
-	setCurrentStyle(styleButton->valueText());
+	QPalette pal = palette();
 
 	if ( styleButton->valueText() == "motif" || styleButton->valueText() == "windows")
 		pal.setColor ( QPalette::Window, color );
@@ -274,9 +266,9 @@ void Widget::changeBackColor(QColor color)
 
 void Widget::changeTextColor(QColor color)
 {
-	QPalette pal = palette();
+	applyStyle(styleButton->valueText());
 
-	setCurrentStyle(styleButton->valueText());
+	QPalette pal = palette();
 
 	if ( styleButton->valueText() == "motif" )
 	{
@@ -309,16 +301,50 @@ void Widget::setCurrentStyle(QString styleText)
 
 		if ( styleText == "maemo5" )
 		{
-			QLabel *label2 = new QLabel("You have chosen <b>MAEMO5 style</b> everything now defaults to system colors");
+			//QLabel *label2 = new QLabel("You have chosen <b>MAEMO5 style</b> everything now defaults to system colors");
+			QLabel *label2 = new QLabel;
+			label2->setText("<font color=#000000>"+QString("You have chosen MAEMO5 style.Default to system colors")+"</font>");
 			QMaemo5InformationBox infoBox;
 			infoBox.setWidget(label2);
+			infoBox.exec();
 		}
 }
 
-void Widget::applyStyle()
+
+void Widget::applyStyle(QString style)
 {
-		if ( styleButton->valueText() != "" )
-			setCurrentStyle(styleButton->valueText());
+		qDebug() << "Applying style " << style;
+
+		if ( style != "" )
+		{
+			setCurrentStyle(style);
+		}
+		else
+		{
+			QLabel *label1 = new QLabel;
+			label1->setText("<font color=#000000>"+ QString("Motif has been used as default style, you could change it.")+ 
+								QString("Maemo style supports only theme colours")+"</font>");
+			label1->setWordWrap(true);
+			QMaemo5InformationBox infoBox;
+			infoBox.setWidget(label1);
+			infoBox.exec();
+			setCurrentStyle("motif");
+		}
+}
+
+void Widget::displayStateChanged(QString displayState)
+{ 
+	if (displayState == QLatin1String(MCE_DISPLAY_OFF_STRING))
+	{
+		_screenOff = true;
+		qDebug() << "Stopping timer now screen is off";
+	}
+	else if (displayState != QLatin1String(MCE_DISPLAY_OFF_STRING))
+	{
+		_screenOff = false;
+		qDebug() << "Starting timer now screen is on";
+		_timer->start(_pollingInterval*60000);
+	}
 }
 
 void Widget::changePollInterval(int value)
